﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Facebook;
using FbAuthWpf.Presenters;

namespace FbAuthWpf
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow
    {
        private readonly MainWindowPresenter _viewPresenter;
        public MainWindow()
        {
            InitializeComponent();
            loginButton.Click += loginButton_Click;
            logoutButton.Click += logoutButton_Click;
            postButton.Click += postButton_Click;
            browseButton.Click += browseButton_Click;
            facebookBrowser.Navigated += facebookBrowser_Navigated;


            _viewPresenter = new MainWindowPresenter(this);
            DataContext = _viewPresenter;
        }

        public WebBrowser Browser
        {
            get { return facebookBrowser; }
        }

        void facebookBrowser_Navigated(Object sender, NavigationEventArgs e)
        {
            var fb = new FacebookClient();
            FacebookOAuthResult oauthResult;            
            if (!fb.TryParseOAuthCallbackUrl(e.Uri, out oauthResult))
                return;

            if (oauthResult.IsSuccess)            
                _viewPresenter.LoginSucceeded(oauthResult);            
            else            
                _viewPresenter.LoginFailed(oauthResult);
        }

        private void loginButton_Click(Object sender, RoutedEventArgs e)
        {
            _viewPresenter.Login();
        }

        private void logoutButton_Click(Object sender, RoutedEventArgs e)
        {
            _viewPresenter.Logout();
        }

        private void postButton_Click(Object sender, RoutedEventArgs e)
        {
            _viewPresenter.PostUpdate();
        }

        private void browseButton_Click(Object sender, RoutedEventArgs e)
        {
            _viewPresenter.BrowseForJpegFile();
        }
    }
}
